<div class="modal fade" id="modal-{{timer.pk}}" style="padding-right: 17px;" aria-modal="true">
    <div class="modal-dialog">
    <div class="modal-content">
        <div class="modal-header">
        <h4 class="modal-title">View Timer</h4>
        <button type="button" class="close" data-dismiss="modal" aria-label="Close">
            <span aria-hidden="true">×</span>
        </button>
        </div>
        <div class="modal-body">
        <div class="card">
            <div class="card-body">
                <p class="text-muted text-center">{{evetimer.name}}</p>
                <div class="list-group list-group-unbordered mb-3">
                    <li class="list-group-item">
                        <b>
                            Location
                        </b> 
                        <a class="float-right">
                            {{evetimer.location}}
                        </a>
                    </li>
                    <li class="list-group-item">
                        <b>
                            Type
                        </b> 
                        <a class="float-right">
                            {{evetimer.type}}
                        </a>
                    </li>
                    <li class="list-group-item">
                        <b>
                            Date
                        </b> 
                        <a class="float-right">
                            {{evetimer.timer|date:'Y-m-d'}}
                        </a>
                    </li>
                    <li class="list-group-item">
                        <b>
                            Timer
                        </b> 
                        <a class="float-right">
                            {{evetimer.timer|date:'H:i:s'}}
                        </a>
                    </li>
                    <li class="list-group-item">
                        <b>
                            Created By
                        </b> 
                        <a class="float-right">
                            {{evetimer.user}}
                        </a>
                    </li>
                </div>
            </div>
            <div class="card-footer">
                
            </div>
        </div>
        </div>
        <div class="modal-footer justify-content-between">
        <button type="button" class="btn btn-default" data-dismiss="modal">Close</button>
        {% if perms.django_eveonline_timerboard.delete_evetimer %}
        <a class="btn btn-danger float-right" href="{% url 'django-eveonline-timerboard-timer-remove' evetimer.pk %}">
            Delete Timer
        </a>
        {% endif %}
        </div>
    </div>
    <!-- /.modal-content -->
    </div>
    <!-- /.modal-dialog -->
</div>